Current Plans:

Add more statistics
Add more mappings (homomesy on m x n x k), (complement +)
Add SSPP generator, use that to add TSPP generator
Add PP generator (all of them), for people who like that ig
Add good documentation 😔 (I'll find out if I can auto generate it using rustdoc, that would be really neat)
Otherwise I'll just write it myself, but maybe I can host it on github pages somehow that would be really neat
- Add anything Colin and Zach need, I've got a giant Colin file I'll go through and add anything useful from
